==> shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17.tar.gz: shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/source/shinken-auto-test-source-linker.js <==
SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER = (function ( self ) {
    self.DOM                 = {};
    self.DOM.FORM            = {};
    self.TEST                = {};
    self.ACTION              = {};
    self.ACTION.FORM         = {};
    //********************************************  DOM   **************************************************//
    self.DOM.getIFrame       = function () {
        return document.getElementById( "synchronizers_list" ).contentWindow.document;
    };
    self.DOM.getBody         = function () {
        return self.DOM.getIFrame().getElementById( 'whole-page' );
    };
    self.DOM.addButton       = function () {
        return self.DOM.getBody().querySelector( '.sync-linker-list .btn-shinken' );
    };
    self.DOM.updateButton    = function ( name ) {
        return self.DOM.getBody().querySelector( '.shinken-synchronizer-row[data-name="' + name + '"] .shinkon-cog' );
    };
    self.DOM.activateButton    = function ( name ) {
        return self.DOM.getBody().querySelector( '.shinken-synchronizer-row[data-name="' + name + '"] .switch-button-wrapper' );
    };
    self.DOM.distantSynchronizerLines    = function () {
        return self.DOM.getBody().querySelectorAll( ".shinken-synchronizer-row" );
    };
    self.DOM.FORM.getIFrameContentWIndow  = function () {
        return document.getElementById( "id-shinken-synchronizer-distant-form" ).contentWindow;
    };
    self.DOM.FORM.getIFrame  = function () {
        return self.DOM.FORM.getIFrameContentWIndow().document;
    };
    self.DOM.FORM.mainInput  = function ( property_name ) {
        return SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.line( property_name, self.DOM.FORM.getIFrame() ).querySelector( '.shinken-prop-cell-action .shinken-input' );
    };
    self.DOM.FORM.booleanButton  = function ( property_name, value ) {
        return SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.line( property_name, self.DOM.FORM.getIFrame() ).querySelector( '.shinken-prop-cell-action .shinken-radio-btn[value="' + value + '"]' );
    };
    self.DOM.FORM.saveButton = function ( property_name ) {
        return self.DOM.FORM.getIFrame().getElementById( 'id-shinken-btn-save' );
    };
    self.DOM.FORM.deleteButton = function ( property_name ) {
        return self.DOM.FORM.getIFrame().getElementById( 'id-shinken-btn-remove' );
    };
    //********************************************  TEST   **************************************************//
    self.TEST.distantSynchronizerList    = function ( timeout, nb_line, activate_status ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'TEST.distantSynchronizerList', 'ADD' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            var _lines = self.DOM.distantSynchronizerLines();
            SHINKEN.TOOLS.TEST_AUTO.___isArrayLengthEqualsTo( _lines, nb_line, "distantSynchronizerList" );
            SHINKEN.TOOLS.TEST_AUTO.___isArrayLengthEqualsTo( activate_status, nb_line, "Problème de structure dans le test" );
            for ( var i = 0, _size_i = _lines.length; i < _size_i; i++ ) {
                SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( parseInt(_lines[i].dataset.isActive), activate_status[i], "Active status pour la ligne " + i );
            }
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
        }, timeout );
        return _to_return;
    };
    //********************************************  ACTION   **************************************************//
    self.ACTION.clickOnAddDistantSynchronizer    = function ( timeout ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.clickOnAddDistantSynchronizer', 'ADD' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
                SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.addButton() );
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
            }
            else {
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
            }
        }, timeout );
        return _to_return;
    };
    self.ACTION.clickOnUpdateDistantSynchronizer = function ( timeout, name ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.clickOnUpdateDistantSynchronizer', name );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            var _dom = self.DOM.updateButton( name );
            if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() && _dom ) {
                SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
                SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, _dom );
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
            }
            else {
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                if ( _dom ) {
                    SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
                }
                else {
                    SHINKEN.TOOLS.TEST_AUTO.addError( "Le don n'existe pas, la dernière action n'a pas été faites" );
                }
            }
        }, timeout );
        return _to_return;
    };
    self.ACTION.clickOnActivateDistantSynchronizer = function ( timeout, name ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.clickOnActivateDistantSynchronizer', name );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.activateButton( name ) );
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
        }, timeout );
        return _to_return;
    };
    self.ACTION.FORM.setValue                    = function ( timeout, property_name, value_to_set ) {
        var _to_return = 500;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.FORM.setValue', property_name + " ==> " + value_to_set );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            SHINKEN.TOOLS.TEST_AUTO_DOM.setValue( 0, self.DOM.FORM.mainInput( property_name ), value_to_set );
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
        }, timeout );
        return _to_return;
    };
    self.ACTION.FORM.setValueBoolean             = function ( timeout, property_name, value_to_set ) {
        var _to_return = 500;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.FORM.setValueBoolean', property_name + " ==> " + value_to_set );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.FORM.booleanButton( property_name, value_to_set ) );
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
        }, timeout );
        return _to_return;
    };
    self.ACTION.FORM.save                        = function ( timeout ) {
        var _to_return = 500;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.FORM.save', '-' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
                SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.FORM.saveButton() );
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
            }
            else {
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
            }
        }, timeout );
        return _to_return;
    };
    self.ACTION.FORM.delete                      = function ( timeout ) {
        var _to_return = 500;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.FORM.delete', '-' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            self.DOM.FORM.getIFrameContentWIndow().confirm=function(){
                return true;
            };
            var dom_element = self.DOM.FORM.deleteButton();
            if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
                SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, dom_element );
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
            }
            else {
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
            }
        }, timeout );
        return _to_return;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER || {} );

==> shinken-enterprise_V02.08.01.06_ALL-LANG_Windows-poller-only_FULL_2023-08-18.tar.gz: shinken-enterprise_V02.08.01.06_ALL-LANG_Windows-poller-only_FULL_2023-08-18/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/source/shinken-auto-test-source-linker.js <==
SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER = (function ( self ) {
    self.DOM                                       = {};
    self.DOM.FORM                                  = {};
    self.TEST                                      = {};
    self.ACTION                                    = {};
    self.ACTION.FORM                               = {};
    //********************************************  DOM   **************************************************//
    self.DOM.getIFrame                             = function () {
        return document.getElementById( "synchronizers_list" ).contentWindow.document;
    };
    self.DOM.getBody                               = function () {
        return self.DOM.getIFrame().getElementById( 'whole-page' );
    };
    self.DOM.addButton                             = function () {
        return self.DOM.getBody().querySelector( '.sync-linker-list .btn-shinken' );
    };
    self.DOM.updateButton                          = function ( name ) {
        return self.DOM.getBody().querySelector( '.shinken-synchronizer-row[data-name="' + name + '"] .shinkon-cog' );
    };
    self.DOM.activateButton                        = function ( name ) {
        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
            return self.DOM.getBody().querySelector( '.shinken-synchronizer-row .switch-button-wrapper[data-source-name="' + name + '"]' );
        }
        return self.DOM.getBody().querySelector( '.shinken-synchronizer-row[data-name="' + name + '"] .switch-button-wrapper' );
    };
    self.DOM.distantSynchronizerLines              = function () {
        return self.DOM.getBody().querySelectorAll( ".shinken-synchronizer-row" );
    };
    //********************************************  DOM FORM  **************************************************//
    self.DOM.FORM.getIFrameContentWIndow           = function () {
        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.BRAVO ) {
            return document.querySelector( '.shinken-window-modal-content' ).getElementsByTagName( 'iframe' )[ 0 ].contentWindow;
        }
        return document.getElementById( "id-shinken-synchronizer-distant-form" ).contentWindow;
    };
    self.DOM.FORM.getIFrame                        = function () {
        return self.DOM.FORM.getIFrameContentWIndow().document;
    };
    self.DOM.FORM.mainInput                        = function ( property_name ) {
        return SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.line( property_name, self.DOM.FORM.getIFrame() ).querySelector( '.shinken-prop-cell-action .shinken-input' );
    };
    self.DOM.FORM.booleanButton                    = function ( property_name, value ) {
        return SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.line( property_name, self.DOM.FORM.getIFrame() ).querySelector( '.shinken-prop-cell-action .shinken-radio-btn[value="' + value + '"]' );
    };
    self.DOM.FORM.saveButton                       = function ( property_name ) {
        return self.DOM.FORM.getIFrame().getElementById( 'id-shinken-btn-save' );
    };
    self.DOM.FORM.deleteButton                     = function ( property_name ) {
        return self.DOM.FORM.getIFrame().getElementById( 'id-shinken-btn-remove' );
    };
    self.DOM.FORM.errorMessage                     = function ( property_name ) {
        return self.DOM.FORM.getIFrame().getElementById( 'saving-log-title-text' );
    };
    //********************************************  TEST   **************************************************//
    self.TEST.distantSynchronizerList              = function ( timeout, nb_line, activate_status ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'TEST.distantSynchronizerList', 'ADD' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            var _lines = self.DOM.distantSynchronizerLines();
            SHINKEN.TOOLS.TEST_AUTO.___isArrayLengthEqualsTo( _lines, nb_line, "distantSynchronizerList" );
            SHINKEN.TOOLS.TEST_AUTO.___isArrayLengthEqualsTo( activate_status, nb_line, "Problème de structure dans le test" );
            for ( var i = 0, _size_i = _lines.length; i < _size_i; i++ ) {
                SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( parseInt( _lines[ i ].dataset.isActive ), activate_status[ i ], "Active status pour la ligne " + i );
            }
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
        }, timeout );
        return _to_return;
    };
    self.TEST.distantSynchronizerListLength              = function ( timeout, nb_line, activate_status ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'TEST.distantSynchronizerList', 'ADD' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            var _lines = self.DOM.distantSynchronizerLines();
            SHINKEN.TOOLS.TEST_AUTO.___isArrayLengthEqualsTo( _lines, nb_line, "distantSynchronizerList" );
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
        }, timeout );
        return _to_return;
    };
    self.TEST.hasFormError                         = function ( timeout ) {
        setTimeout( function () {
            var _dom = self.DOM.FORM.errorMessage();
            SHINKEN.TOOLS.TEST_AUTO.__isVisible( _dom, "Error" );
        }, timeout );
        return 100;
    };
    //********************************************  ACTION   **************************************************//
    self.ACTION.clickOnAddDistantSynchronizer      = function ( timeout ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.clickOnAddDistantSynchronizer', 'ADD' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.addButton() );
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
            }
            else {
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
            }
            SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
        }, timeout );
        return _to_return;
    };
    self.ACTION.clickOnUpdateDistantSynchronizer   = function ( timeout, name ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.clickOnUpdateDistantSynchronizer', name );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            var _dom = self.DOM.updateButton( name );
            if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() && _dom ) {
                SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, _dom );
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
            }
            else {
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                if ( _dom ) {
                    SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
                }
                else {
                    SHINKEN.TOOLS.TEST_AUTO.addError( "Le don n'existe pas, la dernière action n'a pas été faites" );
                }
            }
            SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
        }, timeout );
        return _to_return;
    };
    self.ACTION.clickOnActivateDistantSynchronizer = function ( timeout, name ) {
        var _to_return = 200;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.clickOnActivateDistantSynchronizer', name );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.activateButton( name ) );
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
        }, timeout );
        return _to_return;
    };
    self.ACTION.FORM.setValue                      = function ( timeout, property_name, value_to_set ) {
        var _to_return = 500;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.FORM.setValue', property_name + " ==> " + value_to_set );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            SHINKEN.TOOLS.TEST_AUTO_DOM.setValue( 0, self.DOM.FORM.mainInput( property_name ), value_to_set );
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
        }, timeout );
        return _to_return;
    };
    self.ACTION.FORM.setValueBoolean               = function ( timeout, property_name, value_to_set ) {
        var _to_return = 500;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.FORM.setValueBoolean', property_name + " ==> " + value_to_set );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.FORM.booleanButton( property_name, value_to_set ) );
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK", _to_return );
        }, timeout );
        return _to_return;
    };
    self.ACTION.FORM.save                          = function ( timeout, skip_do_next ) {
        var _to_return = 500;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.FORM.save', '-' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, self.DOM.FORM.saveButton(), true );
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
            }
            else {
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
            }
            if ( !skip_do_next ) {
                SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
            }
        }, timeout );
        return _to_return;
    };
    self.ACTION.FORM.delete                        = function ( timeout ) {
        var _to_return = 500;
        var _uuid      = SHINKEN.TOOLS.TEST_AUTO_LOGGER.add( timeout, 'ACTION.FORM.delete', '-' );
        setTimeout( function () {
            SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "IN_PROGRESS" );
            self.DOM.FORM.getIFrameContentWIndow().confirm = function () {
                return true;
            };
            var dom_element                                = self.DOM.FORM.deleteButton();
            if ( !SHINKEN.TOOLS.TEST_AUTO.hasMessage() ) {
                SHINKEN.TOOLS.TEST_AUTO_DOM.click( 0, dom_element );
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "OK" );
            }
            else {
                SHINKEN.TOOLS.TEST_AUTO_LOGGER.changeElementStatus( _uuid, "NOK" );
                SHINKEN.TOOLS.TEST_AUTO.addError( "Le test comporte des erreurs, la dernière action n'a pas été faites" );
            }
            SHINKEN.HIGHWAY.changeUrl( SHINKEN.TOOLS.TEST_AUTO_PHASE.getNextPhaseLink() );
        }, timeout );
        return _to_return;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_SOURCE_LINKER || {} );
